rebuilder

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2018 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package rebuilder provides a struct which helps with rebuilding indices by adding and managing an index.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Options

type Options struct {
	DB        *layer.DB
	BatchSize int
	DBVersion uint64
	IndexName string
}

Options for *Rebuilder.

type Rebuilder

type Rebuilder struct {
	// contains filtered or unexported fields
}

Rebuilder .

func New

func New(opt Options) *Rebuilder

New creates new *Rebuilder.

func (*Rebuilder) Index

func (rr *Rebuilder) Index() *peripheral.Index

Index shoud be part of indices that are being processed inside passed indexBuilder.

func (*Rebuilder) Rebuild

func (rr *Rebuilder) Rebuild(indexBuilder layer.BeforeCommit) error

Rebuild .

Jump to